@@ -319,7 +319,6 @@ mod test {
             // This is set up to always fail.
             let target = (999, '❌');
             let res1 = mgr.get_or_launch(999, target).await;
-            dbg!(&res1);
             assert!(matches!(res1, Err(Error::UnusableTarget(_))));
 
             let chan3 = mgr.get_nowait(&999);
@@ -388,6 +387,6 @@ mod test {
             assert!(mgr.get_nowait(&3).is_some());
             assert!(mgr.get_nowait(&4).is_some());
             assert!(mgr.get_nowait(&5).is_none());
-        })
+        });
     }
 }
